@@ -1,8 +1,9 @@
-import datetime
+from datetime import datetime
 
 from . import Base
 from sqlalchemy import Column, DateTime, ForeignKey, Integer, String
 
+
 class Availability(Base):
     """ Availability Model for storing when users are available to tutor """
     __tablename__ = "availability"
